package com.goldenwater.slaj.ttsa.service.impl;

import java.util.List;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.goldenwater.slaj.ttsa.mapper.BisTtsaApplWiunMapper;
import com.goldenwater.slaj.ttsa.domain.BisTtsaApplWiun;
import com.goldenwater.slaj.ttsa.service.IBisTtsaApplWiunService;

@Service
public class BisTtsaApplWiunServiceImpl implements IBisTtsaApplWiunService {
    @Autowired
    private BisTtsaApplWiunMapper bisTtsaApplWiunMapper;

    @Override
    public BisTtsaApplWiun selectBisTtsaApplWiunByGuid(String guid) {
        return bisTtsaApplWiunMapper.selectBisTtsaApplWiunByGuid(guid);
    }

    @Override
    public List<BisTtsaApplWiun> selectBisTtsaApplWiunList(BisTtsaApplWiun bisTtsaApplWiun) {
        return bisTtsaApplWiunMapper.selectBisTtsaApplWiunList(bisTtsaApplWiun);
    }

    @Override
    public int insertBisTtsaApplWiun(BisTtsaApplWiun bisTtsaApplWiun) {
        return bisTtsaApplWiunMapper.insertBisTtsaApplWiun(bisTtsaApplWiun);
    }

    @Override
    public int updateBisTtsaApplWiun(BisTtsaApplWiun bisTtsaApplWiun) {
        return bisTtsaApplWiunMapper.updateBisTtsaApplWiun(bisTtsaApplWiun);
    }

    @Override
    public int deleteBisTtsaApplWiunByGuid(String guid) {
        return bisTtsaApplWiunMapper.deleteBisTtsaApplWiunByGuid(guid);
    }

    @Override
    public int deleteBisTtsaApplWiunByGuids(String[] guids) {
        return bisTtsaApplWiunMapper.deleteBisTtsaApplWiunByGuids(guids);
    }
}
